@@ -24,7 +24,8 @@ module MIME
   #  puts MIME::Type.simplified('x-appl/x-zip') # => 'appl/zip'
   #
   class Type
-    VERSION = '1.17.2'
+    # The released version of Ruby MIME::Types
+    VERSION = '1.19'
 
     include Comparable
 
@@ -44,7 +45,7 @@ module MIME
     LTSW_URL      = "http://www.ltsw.se/knbase/internet/%s.htp"
     CONTACT_URL   = "http://www.iana.org/assignments/contact-people.htm#%s"
 
-    # Returns +true+ if the simplified type matches the current 
+    # Returns +true+ if the simplified type matches the current
     def like?(other)
       if other.respond_to?(:simplified)
         @simplified == other.simplified
@@ -138,7 +139,7 @@ module MIME
     #   x-chemical/x-pdb  => pdb
     attr_reader :sub_type
     # Returns the media type of the unmodified MIME type.
-    # 
+    #
     #   text/plain        => plain
     #   x-chemical/x-pdb  => x-pdb
     attr_reader :raw_sub_type
@@ -185,7 +186,7 @@ module MIME
     # The regexp for the operating system that this MIME::Type is specific
     # to.
     attr_accessor :system
-    remove_method :system= ; 
+    remove_method :system= ;
     def system=(os) #:nodoc:
       if os.nil? or os.kind_of?(Regexp)
         @system = os
@@ -359,7 +360,7 @@ module MIME
       #   end
       def from_hash(hash) #:yields MIME::Type.new:
         type = {}
-        hash.each_pair do |k, v| 
+        hash.each_pair do |k, v|
           type[k.to_s.tr('A-Z', 'a-z').gsub(/-/, '_').to_sym] = v
         end
 
@@ -400,7 +401,7 @@ module MIME
           t.registered = mime_type.registered?
 
           mime_type.docs && t.docs = mime_type.docs.dup
-          
+
         end
 
         yield m if block_given?
@@ -564,12 +565,12 @@ module MIME
   # This is originally based on Perl MIME::Types by Mark Overmeer.
   #
   # = Author
-  # Copyright:: Copyright (c) 2002 - 2009 by Austin Ziegler
+  # Copyright:: Copyright 2002–2012 by Austin Ziegler
   #             <austin@rubyforge.org>
-  # Version::   1.17.2
+  # Version::   1.19
   # Based On::  Perl
   #             MIME::Types[http://search.cpan.org/author/MARKOV/MIME-Types-1.27/MIME/Types.pm],
-  #             Copyright (c) 2001 - 2009 by Mark Overmeer
+  #             Copyright 2001–2009 by Mark Overmeer
   #             <mimetypes@overmeer.net>.
   # Licence::   Ruby's, Perl Artistic, or GPL version 2 (or later)
   # See Also::  http://www.iana.org/assignments/media-types/
@@ -577,7 +578,7 @@ module MIME
   #
   class Types
     # The released version of Ruby MIME::Types
-    VERSION = '1.17.2'
+    VERSION = MIME::Type::VERSION
 
       # The data version.
     attr_reader :data_version
@@ -651,10 +652,12 @@ module MIME
     # filename extension. If +platform+ is +true+, then only file types that
     # are specific to the current platform will be returned.
     #
+    # This will always return an array.
+    #
     #   puts "MIME::Types.type_for('citydesk.xml')
-    #     => "#{MIME::Types.type_for('citydesk.xml')}"
+    #     => [application/xml, text/xml]
     #   puts "MIME::Types.type_for('citydesk.gif')
-    #     => "#{MIME::Types.type_for('citydesk.gif')}"
+    #     => [image/gif]
     def type_for(filename, platform = false)
       ext = filename.chomp.downcase.gsub(/.*\./o, '')
       list = @extension_index[ext]
@@ -765,7 +768,7 @@ module MIME
 
           begin
             m = TEXT_FORMAT_RE.match(item).captures
-          rescue Exception => ex
+          rescue Exception
             puts "#{filename}:#{index}: Parsing error in MIME type definitions."
             puts "=> #{line}"
             raise
@@ -814,10 +817,12 @@ module MIME
       # its filename extension. If +platform+ is +true+, then only file
       # types that are specific to the current platform will be returned.
       #
+      # This will always return an array.
+      #
       #   puts "MIME::Types.type_for('citydesk.xml')
-      #     => "#{MIME::Types.type_for('citydesk.xml')}"
+      #     => [application/xml, text/xml]
       #   puts "MIME::Types.type_for('citydesk.gif')
-      #     => "#{MIME::Types.type_for('citydesk.gif')}"
+      #     => [image/gif]
       def type_for(filename, platform = false)
         @__types__.type_for(filename, platform)
       end
